@@ -1,4 +1,6 @@
-htmlSerializer <- function(){
+#' @rdname serializers
+#' @export
+serializer_html <- function(){
   function(val, req, res, errorHandler){
     tryCatch({
       res$setHeader("Content-Type", "text/html; charset=utf-8")
@@ -11,4 +13,4 @@ htmlSerializer <- function(){
   }
 }
 
-.globals$serializers[["html"]] <- htmlSerializer
+.globals$serializers[["html"]] <- serializer_html
