@@ -12,8 +12,11 @@ renderWidget <- function(){
 }
 
 test_that("htmlwidgets serialize properly", {
+  # Solaris doesn't have htmlwidgets available for some reason.
+  skip_on_cran()
+
   w <- renderWidget()
-  val <- htmlwidgetSerializer()(w, list(), PlumberResponse$new(), stop)
+  val <- serializer_htmlwidget()(w, list(), PlumberResponse$new(), stop)
   expect_equal(val$status, 200L)
   expect_equal(val$headers$`Content-Type`, "text/html; charset=utf-8")
   # Check that content is encoded
@@ -27,6 +30,8 @@ test_that("Errors call error handler", {
   }
 
   expect_equal(errors, 0)
-  htmlwidgetSerializer()(parse(text="hi"), list(), PlumberResponse$new("htmlwidget"), err = errHandler)
+  suppressWarnings(
+    serializer_htmlwidget()(parse(text="hi"), list(), PlumberResponse$new("htmlwidget"), err = errHandler)
+  )
   expect_equal(errors, 1)
 })
